Class: IControl::LocalLB::ProfileHttpClass::ProfileHttpClassStatistics
- Inherits:
-
Base::Struct
- Object
- Base::Struct
- IControl::LocalLB::ProfileHttpClass::ProfileHttpClassStatistics
- Defined in:
- lib/icontrol/local_lb/profile_http_class.rb,
lib/icontrol/local_lb/profile_http_class.rb
Overview
A struct that describes profile statistics and timestamp.
Instance Attribute Summary collapse
-
#statistics ⇒ IControl::LocalLB::ProfileHttpClass::ProfileHttpClassStatisticEntrySequence
The statistics for a sequence of profiles.
-
#time_stamp ⇒ IControl::Common::TimeStamp
The time stamp at the time the statistics are gathered.
Instance Attribute Details
#statistics ⇒ IControl::LocalLB::ProfileHttpClass::ProfileHttpClassStatisticEntrySequence
The statistics for a sequence of profiles.
457 458 459 |
# File 'lib/icontrol/local_lb/profile_http_class.rb', line 457 def statistics @statistics end |
#time_stamp ⇒ IControl::Common::TimeStamp
The time stamp at the time the statistics are gathered.
457 458 459 |
# File 'lib/icontrol/local_lb/profile_http_class.rb', line 457 def time_stamp @time_stamp end |