Class: IControl::LocalLB::VirtualServer::VirtualServerHttpClass
- Inherits:
-
Base::Struct
- Object
- Base::Struct
- IControl::LocalLB::VirtualServer::VirtualServerHttpClass
- Defined in:
- lib/icontrol/local_lb/virtual_server.rb,
lib/icontrol/local_lb/virtual_server.rb
Overview
A struct that describes the virtual server’s HTTP class profile name and its priority.
Instance Attribute Summary collapse
-
#priority ⇒ Numeric
The priority value of this profile, used to indicate the order of profile evaluation.
-
#profile_name ⇒ String
The HTTP class profile name.
Instance Attribute Details
#priority ⇒ Numeric
The priority value of this profile, used to indicate the order of profile evaluation.
985 986 987 |
# File 'lib/icontrol/local_lb/virtual_server.rb', line 985 def priority @priority end |
#profile_name ⇒ String
The HTTP class profile name.
985 986 987 |
# File 'lib/icontrol/local_lb/virtual_server.rb', line 985 def profile_name @profile_name end |