Class: IControl::Management::LDAPPasswordEncodingOption
- Inherits:
-
Base::Enumeration
- Object
- Base::Enumeration
- IControl::Management::LDAPPasswordEncodingOption
- Defined in:
- lib/icontrol/management.rb,
lib/icontrol/management.rb
Overview
An enumeration of LDAP password encoding options.
Constant Summary collapse
- LDAP_PASSWORD_ENCODING_ACTIVE_DIRECTORY =
Update Active Directory password, by creating Unicode password and updating unicodePwd attribute.
:LDAP_PASSWORD_ENCODING_ACTIVE_DIRECTORY- LDAP_PASSWORD_ENCODING_CLEAR =
Do not hash the password at all; presume the directory server will do it, if necessary. This is the default.
:LDAP_PASSWORD_ENCODING_CLEAR- LDAP_PASSWORD_ENCODING_CRYPT =
Hash password locally; required for University of Michigan LDAP server, and works with Netscape Directory Server if you're using the UNIX-Crypt hash mechanism and not using the NT Synchronization service.
:LDAP_PASSWORD_ENCODING_CRYPT- LDAP_PASSWORD_ENCODING_EXTENDED_OPERATION =
Use the OpenLDAP password change extended operation to update the password.
:LDAP_PASSWORD_ENCODING_EXTENDED_OPERATION- LDAP_PASSWORD_ENCODING_MD5 =
Digest password using MD5 .
:LDAP_PASSWORD_ENCODING_MD5- LDAP_PASSWORD_ENCODING_NDS =
Remove old password first, then update in cleartext. Necessary for use with Novell Directory Services (NDS).
:LDAP_PASSWORD_ENCODING_NDS