Class: IControl::Management::SNMPConfiguration::DynamicLoadableModule
- Inherits:
-
Base::Struct
- Object
- Base::Struct
- IControl::Management::SNMPConfiguration::DynamicLoadableModule
- Defined in:
- lib/icontrol/management/snmp_configuration.rb,
lib/icontrol/management/snmp_configuration.rb
Overview
This type is deprecated (immediately) and should not be used, in order to ensure proper operation of the system. If the agent is built with support for the UCD-DLMOD-MIB, it is cabable of loading agent MIB modules dynamically at startup through the dlmod directive and during runtime through the use of the UCD-DLMOD-MIB. The directive loads the shared object module file path which uses the module name prefix.
Instance Attribute Summary collapse
-
#module_name ⇒ String
The module name prefix to dynamically load.
-
#module_path ⇒ String
The module path for the module_name prefix.
Instance Attribute Details
#module_name ⇒ String
The module name prefix to dynamically load.
1623 1624 1625 |
# File 'lib/icontrol/management/snmp_configuration.rb', line 1623 def module_name @module_name end |
#module_path ⇒ String
The module path for the module_name prefix.
1623 1624 1625 |
# File 'lib/icontrol/management/snmp_configuration.rb', line 1623 def module_path @module_path end |