Class: IControl::System::SoftwareManagement::SoftwareRepositoryImage
- Inherits:
-
Base::Struct
- Object
- Base::Struct
- IControl::System::SoftwareManagement::SoftwareRepositoryImage
- Defined in:
- lib/icontrol/system/software_management.rb,
lib/icontrol/system/software_management.rb
Overview
A structure with information for describing a specific image.
Instance Attribute Summary collapse
-
#build ⇒ String
The products build number.
-
#build_date ⇒ String
The date this build was created.
-
#chassis_slot_id ⇒ Numeric
is the blade location in the system chassis.
-
#chksum ⇒ String
The md5 checksum of the file.
-
#file_size ⇒ String
The size in bytes of the file.
-
#filename ⇒ String
The filename of the image.
-
#last_modified ⇒ String
The date this file was last modified.
-
#product ⇒ String
The product’s name.
-
#verified ⇒ Object
Verified is True if the md5 is up to date, False if the checksum is being calculated.
-
#version ⇒ String
The product’s version.
Instance Attribute Details
#build ⇒ String
The products build number.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def build @build end |
#build_date ⇒ String
The date this build was created.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def build_date @build_date end |
#chassis_slot_id ⇒ Numeric
is the blade location in the system chassis.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def chassis_slot_id @chassis_slot_id end |
#chksum ⇒ String
The md5 checksum of the file.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def chksum @chksum end |
#file_size ⇒ String
The size in bytes of the file.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def file_size @file_size end |
#filename ⇒ String
The filename of the image.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def filename @filename end |
#last_modified ⇒ String
The date this file was last modified.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def last_modified @last_modified end |
#product ⇒ String
The product’s name.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def product @product end |
#verified ⇒ Object
Verified is True if the md5 is up to date, False if the checksum is being calculated.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def verified @verified end |
#version ⇒ String
The product’s version.
405 406 407 |
# File 'lib/icontrol/system/software_management.rb', line 405 def version @version end |