Class: IControl::System::Statistics::PerformanceGraphDataCSV
- Inherits:
-
Base::Struct
- Object
- Base::Struct
- IControl::System::Statistics::PerformanceGraphDataCSV
- Defined in:
- lib/icontrol/system/statistics.rb,
lib/icontrol/system/statistics.rb
Overview
A struct that describes details of a statistical graph or table in a file, currently in CSV format. During queries, if the user specifies a start_time, end_time, and interval that does not exactly match the corresponding value used within the database, the database will attempt to use to closest time or interval as requested. The actual values used will be returned to the user in this structure.
Instance Attribute Summary collapse
-
#end_time ⇒ Numeric
The actual ending time (seconds since Jan 1, 1970) used to stop retrieving data for the graph/table.
-
#interval ⇒ Numeric
The actual sampling interval in seconds used in creating the graph/table.
-
#object_name ⇒ String
The key or name of the statistical graph/table.
-
#start_time ⇒ Numeric
The actual starting time (seconds since Jan 1, 1970) used to start retrieving data for the graph/table.
-
#statistic_data ⇒ StringSequence
The statistics for the specified graph/table in CSV format.
Instance Attribute Details
#end_time ⇒ Numeric
The actual ending time (seconds since Jan 1, 1970) used to stop retrieving data for the graph/table.
1070 1071 1072 |
# File 'lib/icontrol/system/statistics.rb', line 1070 def end_time @end_time end |
#interval ⇒ Numeric
The actual sampling interval in seconds used in creating the graph/table.
1070 1071 1072 |
# File 'lib/icontrol/system/statistics.rb', line 1070 def interval @interval end |
#object_name ⇒ String
The key or name of the statistical graph/table.
1070 1071 1072 |
# File 'lib/icontrol/system/statistics.rb', line 1070 def object_name @object_name end |
#start_time ⇒ Numeric
The actual starting time (seconds since Jan 1, 1970) used to start retrieving data for the graph/table.
1070 1071 1072 |
# File 'lib/icontrol/system/statistics.rb', line 1070 def start_time @start_time end |
#statistic_data ⇒ StringSequence
The statistics for the specified graph/table in CSV format.
1070 1071 1072 |
# File 'lib/icontrol/system/statistics.rb', line 1070 def statistic_data @statistic_data end |